@@ -9,16 +9,21 @@ Task of kind %s is not registered, please make sure it's imported.
 """.strip()
 
 
+class ImproperlyConfigured(Exception):
+    """Celery is somehow improperly configured."""
+
+
 class NotRegistered(KeyError):
     """The task is not registered."""
 
     def __init__(self, message, *args, **kwargs):
         message = UNREGISTERED_FMT % str(message)
-        super(NotRegistered, self).__init__(message, *args, **kwargs)
+        KeyError.__init__(self, message, *args, **kwargs)
 
 
 class AlreadyRegistered(Exception):
     """The task is already registered."""
+    pass
 
 
 class TimeoutError(Exception):
@@ -34,4 +39,4 @@ class RetryTaskError(Exception):
 
     def __init__(self, message, exc, *args, **kwargs):
         self.exc = exc
-        super(RetryTaskError, self).__init__(message, exc, *args, **kwargs)
+        Exception.__init__(self, message, exc, *args, **kwargs)
