@@ -62,6 +62,6 @@ class TaskSetMeta(models.Model):
 if (django.VERSION[0], django.VERSION[1]) >= (1, 1):
     # keep models away from syncdb/reset if database backend is not
     # being used.
-    if conf.CELERY_BACKEND != 'database':
+    if conf.RESULT_BACKEND != 'database':
         TaskMeta._meta.managed = False
         TaskSetMeta._meta.managed = False
