@@ -6,7 +6,7 @@ from Queue import Queue
 from billiard.serialization import pickle
 
 from celery import conf
-from celery.log import setup_logger
+from celery.log import setup_task_logger
 from celery.utils import gen_unique_id, padlist, timedelta_seconds
 from celery.result import BaseAsyncResult, TaskSetResult, EagerResult
 from celery.execute import apply_async, apply
@@ -208,12 +208,13 @@ class Task(object):
 
     @classmethod
     def get_logger(self, loglevel=None, logfile=None, **kwargs):
-        """Get process-aware logger object.
+        """Get task-aware logger object.
 
-        See :func:`celery.log.setup_logger`.
+        See :func:`celery.log.setup_task_logger`.
 
         """
-        return setup_logger(loglevel=loglevel, logfile=logfile)
+        return setup_task_logger(loglevel=loglevel, logfile=logfile,
+                                 task_kwargs=kwargs)
 
     @classmethod
     def establish_connection(self,
@@ -380,6 +381,11 @@ class Task(object):
 
     @classmethod
     def AsyncResult(self, task_id):
+        """Get AsyncResult instance for this kind of task.
+
+        :param task_id: Task id to get result for.
+
+        """
         return BaseAsyncResult(task_id, backend=self.backend)
 
     def on_retry(self, exc, task_id, args, kwargs):
@@ -439,6 +445,7 @@ class Task(object):
         wrapper.execute_using_pool(pool, loglevel, logfile)
 
     def __repr__(self):
+        """repr(task)"""
         try:
             kind = self.__class__.mro()[1].__name__
         except (AttributeError, IndexError):
@@ -584,14 +591,18 @@ class TaskSet(object):
         return TaskSetResult(taskset_id, subtasks)
 
     def apply_part(self, arglist, taskset_id, publisher):
+        """Apply a single part of the taskset."""
         args, kwargs, opts = padlist(arglist, 3, default={})
         return apply_async(self.task, args, kwargs,
                            taskset_id=taskset_id, publisher=publisher, **opts)
 
     def apply(self):
+        """Applies the taskset locally."""
         taskset_id = gen_unique_id()
         subtasks = [apply(self.task, args, kwargs)
                         for args, kwargs in self.arguments]
+
+        # This will be filled with EagerResults.
         return TaskSetResult(taskset_id, subtasks)
 
     @classmethod
@@ -599,7 +610,7 @@ class TaskSet(object):
         """Apply ``args`` to function by distributing the args to the
         celery server(s)."""
         pickled = pickle.dumps(func)
-        arguments = [[[pickled, arg, {}], {}] for arg in args]
+        arguments = [((pickled, arg, {}), {}) for arg in args]
         return cls(ExecuteRemoteTask, arguments)
 
     @classmethod
@@ -713,12 +724,34 @@ class PeriodicTask(Task):
         return False, rem
 
     def delta_resolution(self, dt, delta):
-        resolution = {3: lambda x: x / 86400,
-                      4: lambda x: x / 3600,
-                      5: lambda x: x / 60}
+        """Round a datetime to the resolution of a timedelta.
+
+        If the timedelta is in days, the datetime will be rounded
+        to the nearest days, if the timedelta is in hours the datetime
+        will be rounded to the nearest hour, and so on until seconds
+        which will just return the original datetime.
+
+            >>> now = datetime.now()
+            >>> now
+            datetime.datetime(2010, 3, 30, 11, 50, 58, 41065)
+            >>> delta_resolution(now, timedelta(days=2))
+            datetime.datetime(2010, 3, 30, 0, 0)
+            >>> delta_resolution(now, timedelta(hours=2))
+            datetime.datetime(2010, 3, 30, 11, 0)
+            >>> delta_resolution(now, timedelta(minutes=2))
+            datetime.datetime(2010, 3, 30, 11, 50)
+            >>> delta_resolution(now, timedelta(seconds=2))
+            datetime.datetime(2010, 3, 30, 11, 50, 58, 41065)
+
+        """
+        delta = self.timedelta_seconds(delta)
+
+        resolutions = ((3, lambda x: x / 86400),
+                       (4, lambda x: x / 3600),
+                       (5, lambda x: x / 60))
+
         args = dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second
-        r = None
-        for res, predicate in resolution.items():
-            if predicate(self.timedelta_seconds(delta)):
-                r = res
-        return datetime(*args[:r])
+        for res, predicate in resolutions:
+            if predicate(delta) >= 1.0:
+                return datetime(*args[:res])
+        return dt
