@@ -1,4 +1,4 @@
-import unittest
+import unittest2 as unittest
 from datetime import timedelta
 
 from celery import states
@@ -28,23 +28,21 @@ class TestDatabaseBackend(unittest.TestCase):
         tid = gen_unique_id()
 
         self.assertFalse(b.is_successful(tid))
-        self.assertEquals(b.get_status(tid), states.PENDING)
-        self.assertTrue(b.get_result(tid) is None)
+        self.assertEqual(b.get_status(tid), states.PENDING)
+        self.assertIsNone(b.get_result(tid))
 
         b.mark_as_done(tid, 42)
         self.assertTrue(b.is_successful(tid))
-        self.assertEquals(b.get_status(tid), states.SUCCESS)
-        self.assertEquals(b.get_result(tid), 42)
-        self.assertTrue(b._cache.get(tid))
-        self.assertTrue(b.get_result(tid), 42)
+        self.assertEqual(b.get_status(tid), states.SUCCESS)
+        self.assertEqual(b.get_result(tid), 42)
 
         tid2 = gen_unique_id()
         result = {"foo": "baz", "bar": SomeClass(12345)}
         b.mark_as_done(tid2, result)
         # is serialized properly.
         rindb = b.get_result(tid2)
-        self.assertEquals(rindb.get("foo"), "baz")
-        self.assertEquals(rindb.get("bar").data, 12345)
+        self.assertEqual(rindb.get("foo"), "baz")
+        self.assertEqual(rindb.get("bar").data, 12345)
 
         tid3 = gen_unique_id()
         try:
@@ -53,19 +51,18 @@ class TestDatabaseBackend(unittest.TestCase):
             pass
         b.mark_as_failure(tid3, exception)
         self.assertFalse(b.is_successful(tid3))
-        self.assertEquals(b.get_status(tid3), states.FAILURE)
-        self.assertTrue(isinstance(b.get_result(tid3), KeyError))
+        self.assertEqual(b.get_status(tid3), states.FAILURE)
+        self.assertIsInstance(b.get_result(tid3), KeyError)
 
     def test_taskset_store(self):
         b = DatabaseBackend()
         tid = gen_unique_id()
 
-        self.assertTrue(b.restore_taskset(tid) is None)
+        self.assertIsNone(b.restore_taskset(tid))
 
         result = {"foo": "baz", "bar": SomeClass(12345)}
         b.save_taskset(tid, result)
         rindb = b.restore_taskset(tid)
-        self.assertTrue(rindb is not None)
-        self.assertEquals(rindb.get("foo"), "baz")
-        self.assertEquals(rindb.get("bar").data, 12345)
-        self.assertTrue(b._cache.get(tid))
+        self.assertIsNotNone(rindb)
+        self.assertEqual(rindb.get("foo"), "baz")
+        self.assertEqual(rindb.get("bar").data, 12345)
