@@ -4,6 +4,7 @@ from datetime import datetime, timedelta
 
 from celery import task
 from celery import messaging
+from celery.utils import gen_unique_id
 from celery.result import EagerResult
 from celery.execute import send_task
 from celery.backends import default_backend
@@ -202,6 +203,12 @@ class TestCeleryTasks(unittest.TestCase):
         cls.run = return_True
         return cls
 
+    def test_AsyncResult(self):
+        task_id = gen_unique_id()
+        result = RetryTask.AsyncResult(task_id)
+        self.assertEqual(result.backend, RetryTask.backend)
+        self.assertEqual(result.task_id, task_id)
+
     def test_ping(self):
         from celery import conf
         conf.ALWAYS_EAGER = True
@@ -429,6 +436,17 @@ class TestPeriodicTask(unittest.TestCase):
         for delta, seconds in deltamap:
             self.assertEqual(MyPeriodic().timedelta_seconds(delta), seconds)
 
+    def test_delta_resolution(self):
+        D = MyPeriodic().delta_resolution
+
+        dt = datetime(2010, 3, 30, 11, 50, 58, 41065)
+        deltamap = ((timedelta(days=2), datetime(2010, 3, 30, 0, 0)),
+                    (timedelta(hours=2), datetime(2010, 3, 30, 11, 0)),
+                    (timedelta(minutes=2), datetime(2010, 3, 30, 11, 50)),
+                    (timedelta(seconds=2), dt))
+        for delta, shoulda in deltamap:
+            self.assertEqual(D(dt, delta), shoulda)
+
     def test_is_due_not_due(self):
         due, remaining = MyPeriodic().is_due(datetime.now())
         self.assertFalse(due)
