@@ -1,10 +1,18 @@
-import unittest
+from __future__ import generators
+
+import unittest2 as unittest
 from Queue import Queue, Empty
 from datetime import datetime, timedelta
 
 from celery.worker.scheduler import Scheduler
 
 
+class MockItem(object):
+
+    def __init__(self, value):
+        self.task_id = value
+
+
 class TestScheduler(unittest.TestCase):
 
     def test_sched_and_run_now(self):
@@ -16,12 +24,12 @@ class TestScheduler(unittest.TestCase):
         def callback():
             callback_called[0] = True
 
-        sched.enter("foo", eta=now, callback=callback)
+        sched.enter(MockItem("foo"), eta=now, callback=callback)
 
         remaining = iter(sched).next()
-        self.assertEquals(remaining, 0)
+        self.assertEqual(remaining, 0)
         self.assertTrue(callback_called[0])
-        self.assertEquals(ready_queue.get_nowait(), "foo")
+        self.assertEqual(ready_queue.get_nowait().task_id, "foo")
 
     def test_sched_run_later(self):
         ready_queue = Queue()
@@ -33,15 +41,14 @@ class TestScheduler(unittest.TestCase):
             callback_called[0] = True
 
         eta = now + timedelta(seconds=10)
-        sched.enter("foo", eta=eta, callback=callback)
+        sched.enter(MockItem("foo"), eta=eta, callback=callback)
 
         remaining = iter(sched).next()
-        self.assertTrue(remaining > 7)
+        self.assertTrue(remaining > 7 or remaining == sched.max_interval)
         self.assertFalse(callback_called[0])
         self.assertRaises(Empty, ready_queue.get_nowait)
 
     def test_empty_queue_yields_None(self):
         ready_queue = Queue()
         sched = Scheduler(ready_queue)
-
-        self.assertTrue(iter(sched).next() is None)
+        self.assertIsNone(iter(sched).next())
