@@ -3,6 +3,7 @@ import time
 import heapq
 
 from celery.worker.revoke import revoked
+from celery import log
 
 DEFAULT_MAX_INTERVAL = 2
 
@@ -16,9 +17,11 @@ class Scheduler(object):
 
     """
 
-    def __init__(self, ready_queue, max_interval=DEFAULT_MAX_INTERVAL):
+    def __init__(self, ready_queue, logger=None,
+            max_interval=DEFAULT_MAX_INTERVAL):
         self.max_interval = float(max_interval)
         self.ready_queue = ready_queue
+        self.logger = logger or log.get_default_logger()
         self._queue = []
 
     def enter(self, item, eta=None, priority=0, callback=None):
